@@ -1,4 +1,5 @@
 import traceback
+import sys
 white = '\033[0m'
 red = '\033[31m'
 green = '\033[32m'
@@ -114,7 +115,7 @@ class sqlite:
             st1 = f"SELECT "
             for x in args.items():
                 gg = ()
-                if x[0] == "select":
+                if x[0] == "select" and x[1] is not None:
                     i = 0
                     for y in x[1]:
                         i += 1
@@ -123,7 +124,7 @@ class sqlite:
                         else:
                             st1 += y + ","
                     st1 += f"FROM {table} "
-                if x[0] == "where":
+                if x[0] == "where" and x[1] is not None:
                     st1 += "WHERE "
                     cc = [x for x in x[1].items()]
                     st2 = ""
@@ -244,29 +245,79 @@ class sqlite:
                 continue
             if ";" in d:
                 command = command +hh
-            print(command)
             try:
                 re = cur.execute(command.replace("\n",""))
                 command = ""
                 print(re)
-            except Exception as e:print(traceback.format_exc())
+            except Exception as e:
+                print(traceback.format_exc())
+                command = ""
         return "Console Exit!"
-h = sqlite("db.db")
-#print(h.dbname)
-h.CreateDb("db.db",{"name":{"time":["INTEGER"],"type":["text"]}})
-#h.shell(h)
-#print(h.conn.description)
-#h.insert("name",[{"time":67,"type":"hello"},{"time":890,"type":"poda"},{"time":67,"type":"i am changed"}])
-#h.update("name",{"time":89,"type":"67 changed to 89"},{"time":67,"type is not null":None})
-#print(h.select(["name"],select=["name.type"],where={"time":89}))
-while True:
-    g = input("->")
-    if g == "quit":
-        print("Bye")
-        break
-    try:exec(g)
-    except:print(traceback.format_exc())
-#h.Reload()
-#print(h.dbname)
+class multiprocess:
+    import multiprocessing as multi
+    pss = []
+    def __init__(self,*arg):
+        ps = []
+        for x in arg:
+            self.process(x)
+        self.schema()
+    def process(self,arg):
+        self.pss.append(arg)
+    def schema(self):
+        self.schema = []
+        for x in self.pss:
+            self.schema.append(x.schema)
+    def execute(self,sql):
+        for x in self.pss:
+            cur = x.execute(sql)
+    def commit(self):
+        for x in self.pss:
+            x.commit()
+    def insert(self,table,data,Except=None):
+        for x in self.pss:
+            x.insert(table,data,Except)
+    def update(self,table,data,where=None):
+        for x in self.pss:
+            x.update(table,data,where)
+    def fetchone(self):
+        gg = []
+        for x in self.pss:
+            gg.append(x.fetchone())
+        return gg
+    def fetchall(self):
+        gg = []
+        for x in self.pss:
+            gg.append(x.fetchall)
+        return gg
+    def CreateDb(self,Dbname,data):
+        if not isinstance(Dbname,list):raise Exception(f"{red}Give the database names in the form of list{white}")
+        i = -1
+        for y in Dbname:
+            i += 1
+            x = self.pss[i]
+            x.CreateDb(y,data)
+    def drop(self,tabel=None):
+        for x in self.pss:
+            x.drop(tabel)
+    def Reload(self):
+        for x in self.pss:
+            x.Reload()
+    def select(self,table,**args):
+        select1 = None
+        where1 = None
+        d = []
+        for x in args.items():
+            column = x[0]
+            val = x[1]
+            if column == "select":
+                select1 = x[1]
+            if column == "where":
+                where1 = x[1]
+        for x in self.pss:
+            d.append(x.select(table,select = select1,where = where1))
+        return d
+    def executescript(self,sql):
+        for x in self.pss:
+            x.executescript(sql)
 
-#print(Error.Errors[1])
\ No newline at end of file
+    
\ No newline at end of file
